﻿//----------------------------------------------------------------------------
// AtlasMaker
// TileGrid - basic tilemap packer for AtlasMaker
// This uses the functionality from the original SpriteGrabber script.
// Use this packer on tiles, or sprites that are all the same size
//
// Author: Richard Dare
// richardjdare@googlemail.com
// http://richardjdare.com 
//----------------------------------------------------------------------------

#include "Packer.jsx"
#include "ImageInfo.jsx"

// make TileGrid inherit from Packer
TileGrid.prototype = new Packer;
TileGrid.prototype.constructor = TileGrid;

//override data members
TileGrid.prototype.name = "Tile Grid";
TileGrid.prototype.allowsRotation = false;

//----------------------------------------------------------------------------
// Constructor
//----------------------------------------------------------------------------
function TileGrid(){
	this.docWidth = 0;
	this.docHeight= 0;
	this.docCols = 0;
	this.docRows = 0;
};

//----------------------------------------------------------------------------
// Init() - called when this packer is selected
//----------------------------------------------------------------------------
TileGrid.prototype.Init = function(width,height){
	this.docWidth = width;
	this.docHeight= height;
	this.docCols = 0;
	this.docRows = 0;
};

//----------------------------------------------------------------------------
// Calculate() - Create the tile grid
//----------------------------------------------------------------------------
TileGrid.prototype.Calculate = function(srcImages){
	// scan through the images and work out how big our tiles are

	var tileWidth =0;
	var tileHeight=0;

	for(var v in srcImages)
	{
		var i = srcImages[v];
		if(i.width > tileWidth)
			tileWidth = i.width;
		if(i.height > tileHeight)
			tileHeight = i.height;
	}

    // add on a margin
    tileWidth+=this.margin*2;
    tileHeight+=this.margin*2;

	// calculate rows, columns, number of pages needed
	this.docCols = Math.floor(this.docWidth/tileWidth);
	this.docRows = Math.floor(this.docHeight/tileHeight);

	var spritesPerPage = this.docCols * this.docRows;
	
	var numPages = Math.ceil(srcImages.length / spritesPerPage);

    // rjd: this will be displayed on the atlasmaker main ui
    this.statusMessage = "Rows:"+srcImages.length / this.docCols + "  Columns:"+ this.docCols + "  Tile Size:"+tileWidth+"px x "+tileHeight+"px";

	var count =0;
	for(var p=0;p<numPages;p++)
	{
		for(var y=0;y<this.docRows;y++)
		{
			for(var x=0;x<this.docCols;x++)
			{
				if(count>=srcImages.length)
					return true;

				var i = srcImages[count];
				i.posX = x * tileWidth;
				i.posY = y * tileHeight;
				i.imagePlaced = true;

				i.pageIndex = p;
				count++;
			}
		}
	}
	return true;
};